Welcome to threedigrid's documentation!
=======================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   introduction
   functionalities
   files
   genindex
   history
